<!--

@license Apache-2.0

Copyright (c) 2024 The Stdlib Authors.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

   http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

-->

# isNonPositiveFinite

> Test if a value is a number having a nonpositive finite value.

<section class="usage">

## Usage

```javascript
var isNonPositiveFinite = require( '@stdlib/assert/is-nonpositive-finite' );
```

#### isNonPositiveFinite( value )

Tests if a `value` is a `number` having a nonpositive finite value.

<!-- eslint-disable no-new-wrappers -->

```javascript
var Number = require( '@stdlib/number/ctor' );
var NINF = require('@stdlib/constants/float64/ninf');

var bool = isNonPositiveFinite( -5.0 );
// returns true

bool = isNonPositiveFinite( NINF );
// returns false

bool = isNonPositiveFinite( new Number( -5.0 ) );
// returns true

bool = isNonPositiveFinite( -3.14 );
// returns true

bool = isNonPositiveFinite( 5.0 );
// returns false

bool = isNonPositiveFinite( null );
// returns false
```

#### isNonPositiveFinite.isPrimitive( value )

Tests if a `value` is a primitive `number` having a nonpositive finite value.

<!-- eslint-disable no-new-wrappers -->

```javascript
var Number = require( '@stdlib/number/ctor' );

var bool = isNonPositiveFinite.isPrimitive( -3.0 );
// returns true

bool = isNonPositiveFinite.isPrimitive( new Number( -3.0 ) );
// returns false
```

#### isNonPositiveFinite.isObject( value )

Tests if a `value` is a `Number` object having a nonpositive finite value.

<!-- eslint-disable no-new-wrappers -->

```javascript
var Number = require( '@stdlib/number/ctor' );

var bool = isNonPositiveFinite.isObject( -3.0 );
// returns false

bool = isNonPositiveFinite.isObject( new Number( -3.0 ) );
// returns true
```

</section>

<!-- /.usage -->

<section class="examples">

## Examples

<!-- eslint-disable no-new-wrappers -->

<!-- eslint no-undef: "error" -->

```javascript
var Number = require( '@stdlib/number/ctor' );
var isNonPositiveFinite = require( '@stdlib/assert/is-nonpositive-finite' );
var NINF = require('@stdlib/constants/float64/ninf');

var bool = isNonPositiveFinite( -5.0 );
// returns true

bool = isNonPositiveFinite( NINF );
// returns false

bool = isNonPositiveFinite( new Number( -5.0 ) );
// returns true

bool = isNonPositiveFinite( 0.0 );
// returns true

bool = isNonPositiveFinite( -3.14 );
// returns true

bool = isNonPositiveFinite( 5.0 );
// returns false

bool = isNonPositiveFinite( '-5' );
// returns false

bool = isNonPositiveFinite( null );
// returns false
```

</section>

<!-- /.examples -->

<!-- Section for related `stdlib` packages. Do not manually edit this section, as it is automatically populated. -->

<section class="related">

</section>

<!-- /.related -->

<!-- Section for all links. Make sure to keep an empty line after the `section` element and another before the `/section` close. -->

<section class="links">

</section>

<!-- /.links -->
